@@ -1,3 +1,5 @@
+"""Interface for interacting with an nft collection contract"""
+
 from thirdweb.constants.role import Role
 from thirdweb.core.classes.contract_metadata import ContractMetadata
 from thirdweb.core.classes.contract_platform_fee import ContractPlatformFee
@@ -7,6 +9,7 @@ from thirdweb.core.classes.contract_sales import ContractPrimarySale
 from thirdweb.core.classes.contract_wrapper import ContractWrapper
 from thirdweb.common.nft import upload_or_extract_uri, upload_or_extract_uris
 from thirdweb.core.classes.erc_721 import ERC721
+from thirdweb.core.classes.erc_721_signature_minting import ERC721SignatureMinting
 from thirdweb.abi import TokenERC721
 
 from thirdweb.core.classes.ipfs_storage import IpfsStorage
@@ -28,12 +31,12 @@ class NFTCollection(ERC721):
     contract_type: Final[ContractType] = ContractType.NFT_COLLECTION
     contract_roles: Final[List[Role]] = [Role.ADMIN, Role.MINTER, Role.TRANSFER]
 
-    schema = NFTCollectionContractMetadata
     metadata: ContractMetadata[TokenERC721, NFTCollectionContractMetadata]
     roles: ContractRoles
     primary_sale: ContractPrimarySale[TokenERC721]
     platform_fee: ContractPlatformFee[TokenERC721]
     royalty: ContractRoyalty[TokenERC721]
+    signature: ERC721SignatureMinting
 
     def __init__(
         self,
@@ -47,11 +50,16 @@ class NFTCollection(ERC721):
         contract_wrapper = ContractWrapper(abi, provider, signer, options)
         super().__init__(contract_wrapper, storage)
 
-        self.metadata = ContractMetadata(contract_wrapper, storage, self.schema)
+        self.metadata = ContractMetadata(
+            contract_wrapper, storage, NFTCollectionContractMetadata
+        )
         self.roles = ContractRoles(contract_wrapper, self.contract_roles)
         self.primary_sale = ContractPrimarySale(contract_wrapper)
         self.platform_fee = ContractPlatformFee(contract_wrapper)
         self.royalty = ContractRoyalty(contract_wrapper, self.metadata)
+        self.signature = ERC721SignatureMinting(
+            contract_wrapper, self.roles, self._storage
+        )
 
     """
     WRITE FUNCTIONS
